==> haskell-hspec-meta-2.11.4-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-meta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-meta
version:              2.11.4
visibility:           public
id:                   hspec-meta-2.11.4-FsvvQjw9FjkaE5lmtl781
key:                  hspec-meta-2.11.4-FsvvQjw9FjkaE5lmtl781
license:              MIT
copyright:
    (c) 2011-2023 Simon Hengel,
    (c) 2011-2012 Trystan Spangler,
    (c) 2011 Greg Weber

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://hspec.github.io/
synopsis:             A version of Hspec which is used to test Hspec itself
description:
    A stable version of Hspec which is used to test the
    in-development version of Hspec.

category:             Testing
abi:                  832f3f840ad79f891e8535768258e872
exposed:              True
exposed-modules:      Test.Hspec.Discover Test.Hspec.Meta
hidden-modules:
    Control.Concurrent.Async Data.Algorithm.Diff Test.Hspec
    Test.Hspec.Formatters Test.Hspec.QuickCheck Test.Hspec.Runner
    GetOpt.Declarative GetOpt.Declarative.Environment
    GetOpt.Declarative.Interpret GetOpt.Declarative.Types
    GetOpt.Declarative.Util NonEmpty Test.Hspec.Core.Clock
    Test.Hspec.Core.Compat Test.Hspec.Core.Config
    Test.Hspec.Core.Config.Definition Test.Hspec.Core.Config.Options
    Test.Hspec.Core.Example Test.Hspec.Core.Example.Location
    Test.Hspec.Core.FailureReport Test.Hspec.Core.Format
    Test.Hspec.Core.Formatters Test.Hspec.Core.Formatters.Diff
    Test.Hspec.Core.Formatters.Internal
    Test.Hspec.Core.Formatters.Pretty
    Test.Hspec.Core.Formatters.Pretty.Parser
    Test.Hspec.Core.Formatters.Pretty.Parser.Parser
    Test.Hspec.Core.Formatters.Pretty.Unicode
    Test.Hspec.Core.Formatters.V1 Test.Hspec.Core.Formatters.V1.Free
    Test.Hspec.Core.Formatters.V1.Internal
    Test.Hspec.Core.Formatters.V1.Monad Test.Hspec.Core.Formatters.V2
    Test.Hspec.Core.Hooks Test.Hspec.Core.QuickCheck
    Test.Hspec.Core.QuickCheckUtil Test.Hspec.Core.Runner
    Test.Hspec.Core.Runner.Eval Test.Hspec.Core.Runner.JobQueue
    Test.Hspec.Core.Runner.PrintSlowSpecItems
    Test.Hspec.Core.Runner.Result Test.Hspec.Core.Shuffle
    Test.Hspec.Core.Spec Test.Hspec.Core.Spec.Monad
    Test.Hspec.Core.Timer Test.Hspec.Core.Tree Test.Hspec.Core.Util
    Paths_hspec_meta

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hspec-meta-2.11.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hspec-meta-2.11.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hspec-meta-2.11.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-meta
hs-libraries:         HShspec-meta-2.11.4-FsvvQjw9FjkaE5lmtl781
depends:
    HUnit-1.6.2.0-DydRkK1Ty562EFYgxreweA
    QuickCheck-2.15.0.1-4xuIFLc8qeJEyhSxLjWE4D
    ansi-terminal-1.1-6H4MdlQ9LS5JB7dL181Y6t array-0.5.6.0
    base-4.18.2.1 call-stack-0.4.0-2bP2isqo6m56I7hpBeHX0O
    deepseq-1.4.8.1 directory-1.3.8.5 filepath-1.4.300.1
    haskell-lexer-1.2-1vamZPabniXHcMPDyEaor0
    hspec-expectations-0.8.4-JRz47SURfXgGxfIuVeuxEa process-1.6.19.0
    quickcheck-io-0.2.0-FwErxsQLKaeFMZ1V7T4M6Y
    random-1.2.1.3-A742XuHL3SJDTNKz9BIvTb stm-2.5.1.0
    tf-random-0.5-BNk6V1AnHCU5gNtyoOmhyv time-1.12.2
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-hspec-meta/html/hspec-meta.haddock
haddock-html:         /usr/share/doc/haskell-hspec-meta/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-meta-2.11.4-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-meta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-meta
version:              2.11.4
visibility:           public
id:                   hspec-meta-2.11.4-527VJt8lCwmLQU6BGs6pET
key:                  hspec-meta-2.11.4-527VJt8lCwmLQU6BGs6pET
license:              MIT
copyright:
    (c) 2011-2023 Simon Hengel,
    (c) 2011-2012 Trystan Spangler,
    (c) 2011 Greg Weber

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://hspec.github.io/
synopsis:             A version of Hspec which is used to test Hspec itself
description:
    A stable version of Hspec which is used to test the
    in-development version of Hspec.

category:             Testing
abi:                  f41f5ca68f18b20312f3e2ad79962e55
exposed:              True
exposed-modules:      Test.Hspec.Discover Test.Hspec.Meta
hidden-modules:
    Control.Concurrent.Async Data.Algorithm.Diff Test.Hspec
    Test.Hspec.Formatters Test.Hspec.QuickCheck Test.Hspec.Runner
    GetOpt.Declarative GetOpt.Declarative.Environment
    GetOpt.Declarative.Interpret GetOpt.Declarative.Types
    GetOpt.Declarative.Util NonEmpty Test.Hspec.Core.Clock
    Test.Hspec.Core.Compat Test.Hspec.Core.Config
    Test.Hspec.Core.Config.Definition Test.Hspec.Core.Config.Options
    Test.Hspec.Core.Example Test.Hspec.Core.Example.Location
    Test.Hspec.Core.FailureReport Test.Hspec.Core.Format
    Test.Hspec.Core.Formatters Test.Hspec.Core.Formatters.Diff
    Test.Hspec.Core.Formatters.Internal
    Test.Hspec.Core.Formatters.Pretty
    Test.Hspec.Core.Formatters.Pretty.Parser
    Test.Hspec.Core.Formatters.Pretty.Parser.Parser
    Test.Hspec.Core.Formatters.Pretty.Unicode
    Test.Hspec.Core.Formatters.V1 Test.Hspec.Core.Formatters.V1.Free
    Test.Hspec.Core.Formatters.V1.Internal
    Test.Hspec.Core.Formatters.V1.Monad Test.Hspec.Core.Formatters.V2
    Test.Hspec.Core.Hooks Test.Hspec.Core.QuickCheck
    Test.Hspec.Core.QuickCheckUtil Test.Hspec.Core.Runner
    Test.Hspec.Core.Runner.Eval Test.Hspec.Core.Runner.JobQueue
    Test.Hspec.Core.Runner.PrintSlowSpecItems
    Test.Hspec.Core.Runner.Result Test.Hspec.Core.Shuffle
    Test.Hspec.Core.Spec Test.Hspec.Core.Spec.Monad
    Test.Hspec.Core.Timer Test.Hspec.Core.Tree Test.Hspec.Core.Util
    Paths_hspec_meta

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hspec-meta-2.11.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hspec-meta-2.11.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hspec-meta-2.11.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-meta
hs-libraries:         HShspec-meta-2.11.4-527VJt8lCwmLQU6BGs6pET
depends:
    HUnit-1.6.2.0-DydRkK1Ty562EFYgxreweA
    QuickCheck-2.15.0.1-6GEGPgW6PY5CA5PnU98uYH
    ansi-terminal-1.1-6H4MdlQ9LS5JB7dL181Y6t array-0.5.6.0
    base-4.18.2.1 call-stack-0.4.0-2bP2isqo6m56I7hpBeHX0O
    deepseq-1.4.8.1 directory-1.3.8.5 filepath-1.4.300.1
    haskell-lexer-1.2-1vamZPabniXHcMPDyEaor0
    hspec-expectations-0.8.4-JRz47SURfXgGxfIuVeuxEa process-1.6.19.0
    quickcheck-io-0.2.0-6o3vbEjlx9BI4ezxJTw65V
    random-1.2.1.3-HzFGhfPSv5b3eeTVe0g48p stm-2.5.1.0
    tf-random-0.5-GMT3Oh0DqaxHxtJiGMNr4g time-1.12.2
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-hspec-meta/html/hspec-meta.haddock
haddock-html:         /usr/share/doc/haskell-hspec-meta/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
